@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2014 by Elvis Angelaccio <elvis.angelaccio@kdemail.net>
+    Copyright (C) 2014 by Elvis Angelaccio <elvis.angelaccio@kde.org>
 
     This file is part of Kronometer.
 
@@ -39,7 +39,7 @@ int main (int argc, char **argv)
     auto aboutData = KAboutData {
         QStringLiteral("kronometer"),   // componentName
         i18nc("KAboutData display name", "Kronometer"),
-        QStringLiteral("2.1.1"),    // version
+        QStringLiteral("2.1.2"),    // version
         i18n("Kronometer is a simple stopwatch application"), // shortDescription
         KAboutLicense::GPL_V2,    // licenseType
         i18n("Copyright (C) 2014-2016 Elvis Angelaccio"),    // copyrightStatement
@@ -50,7 +50,7 @@ int main (int argc, char **argv)
     aboutData.addAuthor(
         i18n("Elvis Angelaccio"),
         i18n("Maintainer"),
-        QStringLiteral("elvis.angelaccio@kdemail.net"),
+        QStringLiteral("elvis.angelaccio@kde.org"),
         QStringLiteral("http://aelog.org")
     );
 
